@@ -872,6 +872,54 @@ namespace apg {
             }
         }
 
+        hypernode<I> onecell_recurse(hypernode<I> hnode) {
+
+            if (hnode.index == 0) {
+                return hnode;
+            } else if (hnode.depth == 0) {
+
+                kiventry<nicearray<uint64_t, 4*N>, I, J >* pptr = ind2ptr_leaf(hnode.index);
+                nicearray<uint64_t, 4*N> outleaf = {0ull};
+
+                for (int j = 0; j < 4; j++) {
+                    uint64_t l = pptr->key.x[j];
+                    for (int i = 1; i < N; i++) {
+                        l |= pptr->key.x[4*i+j];
+                    }
+                    if (l == 0) { continue; }
+                    l &= (-l); // extract one bit
+                    for (int i = 0; i < N; i++) {
+                        outleaf.x[4*i+j] = l;
+                    }
+                    break;
+                }
+
+                I res = make_leaf(outleaf);
+                return hypernode<I>(res, 0);
+
+            } else {
+
+                kiventry<nicearray<I, 4>, I, J >* pptr = ind2ptr_nonleaf(hnode.depth, hnode.index);
+
+                nicearray<I, 4> cc = {(I) 0, (I) 0, (I) 0, (I) 0};
+
+                if (pptr->key.x[0]) {
+                    cc.x[0] = onecell_recurse(hypernode<I>(pptr->key.x[0], hnode.depth - 1)).index;
+                } else if (pptr->key.x[1]) {
+                    cc.x[1] = onecell_recurse(hypernode<I>(pptr->key.x[1], hnode.depth - 1)).index;
+                } else if (pptr->key.x[2]) {
+                    cc.x[2] = onecell_recurse(hypernode<I>(pptr->key.x[2], hnode.depth - 1)).index;
+                } else if (pptr->key.x[3]) {
+                    cc.x[3] = onecell_recurse(hypernode<I>(pptr->key.x[3], hnode.depth - 1)).index;
+                }
+
+                hypernode<I> xcc = make_nonleaf_hn(hnode.depth, cc);
+                return xcc;
+
+            }
+
+        }
+
         hypernode<I> brand_recurse(hypernode<I> hnode, std::map<std::pair<I, uint32_t>, I> *memmap, bool disjunctive) {
 
             if (N == 1) { return hnode; }
