@@ -5,12 +5,16 @@ from collections import Sequence, defaultdict
 
 def get_symmetries(rulestring):
 
+    validsyms = ["1x256", "2x128", "4x64", "8x32", "C1"] # asymmetric soups
+
     if rulestring[-1].lower() == 'h':
-        validsyms = ["1x256", "2x128", "4x64", "8x32", "C1", "C2_4", "C2_1", "C3_1", "C6",
-                 "D2_x", "D2_xo", "D4_x4", "D4_x1", "D6_1", "D6_1o", "D12"]
+        validsyms += ["C2_4", "C2_1", "C3_1", "C6", "D2_x", "D2_xo", "D4_x4", "D4_x1", "D6_1", "D6_1o", "D12"]
     else:
-        validsyms = ["1x256", "2x128", "4x64", "8x32", "C1", "C2_4", "C2_2", "C2_1", "C4_4", "C4_1",
-                 "D2_+2", "D2_+1", "D2_x", "D4_+4", "D4_+2", "D4_+1", "D4_x4", "D4_x1", "D8_4", "D8_1"]
+        validsyms += ["C2_4", "C2_2", "C2_1", "C4_4", "C4_1",
+                        "D2_+2", "D2_+1", "D2_x", "D4_+4", "D4_+2", "D4_+1", "D4_x4", "D4_x1", "D8_4", "D8_1"]
+
+    if (re.match('^b0?1?2?3?4?5?6?7?8?s0?1?2?3?4?5?6?7?8?$', rulestring)):
+        validsyms += ["G1", "H2_+1", "H2_+2", "H4_+1", "H4_+2", "H4_+4"] # GPU symmetries
 
     return validsyms
 
@@ -84,8 +88,12 @@ def download_samples(lt, apgcode, rule, domain='https://gol.hatsya.co.uk', tempf
             if '/' not in l:
                 continue
             symmetry, seed = tuple(l.strip().split('/')[:2])
-            if len(symmetry) > 50:
+            if (len(symmetry) > 50) or (len(symmetry) == 0):
                 continue
+            if (symmetry[0] == 'G'):
+                symmetry = 'C' + symmetry[1:]
+            elif (symmetry[0] == 'H'):
+                symmetry = 'D' + symmetry[1:]
             samples[symmetry].append(seed)
 
     samples = {k : SampleSoupList(lt, rule, k, v) for (k, v) in samples.items() if validate_symmetry(rule, k, False)}
