@@ -14,6 +14,22 @@ class TestGoL(unittest.TestCase):
         self.sess = lifelib.load_rules('b3s23')
         self.lt = self.sess.lifetree(memory=1000, n_layers=4)
 
+    def test_components(self):
+
+        pat = self.lt.pattern('''7b3o5b3o16b3o5b3o$6bo2bo5bo2bo15bo2bo3bo2bo$6bo3bo3bo3bo15bo9bo$7b4o3b
+4o14b2o2bobobobo2b2o$8bobo3bobo15b2o2bobobobo2b2o$31bo5bo3bo5bo$10bo3b
+o17bo2bobo3bobo2bo$5bo4b2ob2o4bo13b2o9b2o$5b2o3b2ob2o3b2o14bo9bo$10b2o
+b2o$9b2o3b2o16b2o11b2o$9bo5bo16b2o11b2o2$36b2o3b2o$36b2o3b2o$19b3o8b3o
+$3b3o3b2o3b2o3bo2bo7bo2bo12b3o$3bo2bo2b2o3b2o2bo3bo7bob2o12bo2bo$3bo
+14bo3bo23bo2bo$4bobo11bo2bo$bo3bo13b2o12b3o5bob2o3bo2bo$bo25b2o4b2o7b
+3o6bo$o26b3o2b4o10b2o2bo$29bo19bo$3bobo41b2o$3b3o$2bo2b3ob3o35bo$3b5o
+3bo29b2o3bobo$2bobo2b2o2bo2bo26b3o2bobo$bobo5bo5bo$2bo7b2o4bo24b2obo$
+3b2o6b3obo19bo6bo4b2o2bo$35bobo6bo6bo$35bo3b2o3bo$36bo4bo5b2o$36bo4bo$
+37bo2bo!''', 'b3s23')
+
+        ncomps = len(pat.components())
+        self.assertEqual(ncomps, 41)
+
     def test_samples(self):
 
         pat = self.lt.pattern('xp40_33zxs48g69gvzx3021zy833')
